CLI de Transit Gateway
La línea de comando IBM Cloud® Transit Gateway proporciona una interfaz con el servicio Transit Gateway. Puede utilizar la CLI para crear y gestionar pasarelas y conexiones y para ver una lista de las ubicaciones disponibles para las pasarelas.
Antes de empezar
Siga las instrucciones para instalar la interfaz de línea de mandatos de Transit Gateway, que se implementa como un complemento de CLI de IBM Cloud.
-
Instale la CLI de IBM Cloud.
-
Instale el plugin de la CLI de
tg-cli/tgen la CLI de IBM Cloud.Para instalar:
ibmcloud plugin install tg
Si va a utilizar la interfaz de línea de mandatos con un punto final privado virtual (VPE), debe establecer la variable siguiente:
export IBMCLOUD_TG_API_ENDPOINT=private.transit.cloud.ibm.com
ibmcloud plugin show tg
Mostrar información sobre el plugin de CLI de Transit Gateway.
ibmcloud plugin show tg
Pasarelas de tránsito
Esta sección ofrece información sobre comandos de la interfaz de línea de comandos (CLI) para las funciones de la pasarela.
ibmcloud tg gateway
Recuperar detalles sobre una pasarela específica.
ibmcloud tg gateway|gw GATEWAY_ID [--output json] [-h, --help]
Opciones de comando
GATEWAY_ID- ID de la pasarela sobre la que desea obtener información.
--output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Solicitar detalles sobre la pasarela.
ibmcloud tg gw $gateway
ibmcloud tg gateways
Ver una lista de las pasarelas de tránsito.
ibmcloud tg gateways|gws [--output json] [-h, --help]
Opciones de comando
--output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Otros comandos requieren un ID de puerta de enlace. Guarda el ID como variable de entorno para poder utilizarlo más adelante, por ejemplo:
gateway="bdf8fa2b-c518-9999-9028-f3c9ece86159"
ibmcloud tg gateway-create
Cree una pasarela de tránsito.
ibmcloud tg gateway-create|gwc --name NAME --location LOCATION [--routing ROUTING] [--redundancy-group GROUP_NAME] [--redundancy-group-id GROUP_ID] [--gre-enhanced-route-propagation true | false] [--resource-group-id RES_GROUP_ID] [--output json] [-h, --help]
Opciones de comando
--name-
Nombre de la nueva pasarela.
--location-
Ubicación de la puerta de enlace (consulta los valores posibles utilizando
ibmcloud tg locations) --routing-
Enrutamiento de recursos de puerta de enlace (
global|local). Seleccioneglobalpara conectar recursos entre regiones. El valor predeterminado eslocal. --redundancy-group-
Opcional: Especifica el grupo de redundancia de una pasarela de tránsito global por su nombre. Si el nombre del grupo no existe, se crea. Si existe, la puerta de enlace se une al grupo.
Válido únicamente cuando
--routing globalse especifica. --redundancy-group-id-
Opcional: Especifica el ID de un grupo de redundancia existente para una pasarela de tránsito global. Utilice esta opción cuando el grupo de redundancia ya exista y desee incorporar la pasarela al mismo mediante su ID.
Válido únicamente cuando
--routing globalse especifica.Los grupos de redundancia solo son compatibles con las pasarelas de tránsito globales.
--resource-group-id-
Opcional: ID del grupo de recursos de la puerta de enlace. Si no se especifica, se utiliza el grupo de recursos predeterminado.
--gre-enhanced-route-propagation-
Opcional: Especifique si desea habilitar la propagación de rutas a través de todos los GRE conectados a la misma puerta de enlace de tránsito. Los valores válidos son
truey (falsepor defecto). --output json-
Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h-
Opcional: Obtener ayuda sobre este comando.
Ejemplo
Cree una puerta de enlace que se llame myGateway en us-south con enrutamiento local y que utilice el grupo de recursos predeterminado.
ibmcloud tg gwc --name myGateway --location us-south
ibmcloud tg gateway-delete
Suprimir una pasarela existente.
ibmcloud tg gateway-delete|gwd GATEWAY_ID [-f, --force] [-h, --help]
Opciones de comando
GATEWAY_ID- ID de la puerta de enlace que desea eliminar.
--force | -f- Opcional: Forzar la eliminación sin confirmación.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Suprimir la pasarela sin confirmación.
ibmcloud tg gwd $gateway -f
ibmcloud tg gateway-update
Actualizar las propiedades de una pasarela existente.
ibmcloud tg gateway-update|gwu GATEWAY_ID [--name NAME] [--routing ROUTING] [--redundancy-group GROUP_NAME] [--gre-enhanced-route-propagation true | false] [--output json] [-h, --help]
Opciones de comando
GATEWAY_ID- ID de la pasarela que desea actualizar.
--name- Opcional: Nuevo nombre de la pasarela.
--routing- Opcional: Enrutamiento de recursos de puerta de enlace (
global|local). Seleccione global para conectar recursos entre regiones. Para cambiar el enrutamiento de aglobal,locales necesario que todas las conexiones existentes seanlocal.
El enrutamiento no se puede modificar si la puerta de enlace forma parte de un grupo de redundancia.
--redundancy-group-
Opcional: Actualiza el nombre del grupo de redundancia al que pertenece la pasarela. Solo es válido cuando la puerta de enlace ya forma parte de un grupo de redundancia y el enrutamiento global está habilitado. Al cambiar el nombre del grupo, este se actualiza en todas las puertas de enlace de tránsito asociadas.
--gre-enhanced-route-propagation-
Opcional: Especifique si desea habilitar la propagación de rutas a través de todos los GRE conectados a la misma puerta de enlace de tránsito. Los valores válidos son
truey (falsepor defecto).Después de cambiar este valor, espere unos minutos para que el cambio surta efecto.
--output json-
Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h-
Opcional: Obtener ayuda sobre este comando.
Ejemplo
Actualiza la puerta de enlace con un valor de enrutamiento de global.
ibmcloud tg gwu $gateway --routing global
Conexiones
Esta sección ofrece información sobre comandos de la interfaz de línea de comandos (CLI) para las funciones de conexión.
ibmcloud tg acc-connections
Enumera todas las conexiones de cuentas en la pasarela de tránsito.
ibmcloud tg acc-connections|ac [--network-id NETWORK_ID] [--network-type NETWORK_TYPE] [--all-pages] [--limit NUMERIC_VALUE] [--output json] [-h, --help]
Opciones de comando
--network-id-
Opcional. Para
classic, no establezca un valor. Utilice el CRN para todos los demás tipos de red. Por ejemplo, para averiguar el CRN de una VPC:ibmcloud is vpc VPC_ID --json--network-type: Opcional. Tipo de red de la conexión. Los valores son
classic,directlink,power_virtual_server,vpn_gateway,vpc, y.dynamic_route_serverBeta--all-pages- Opcional: Lista todas las conexiones independientemente de si se especifica un tamaño
--limit. --limit NUMERIC_VALUE- Opcional: El número máximo de recursos a devolver por página. El límite predeterminado es
50. Valores posibles:1≤ valor ≤500 --output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplos
Enumera todas las conexiones de la cuenta:
ibmcloud tg acc-connections|ac
Lista las conexiones de cuentas filtradas por tipo de red:
ibmcloud tg acc-connections|ac --network-type vpc|classic|directlink|vpn_gateway|power_virtual_server|dynamic_route_server [Beta]{: tag-cyan}
ibmcloud tg connection
Recuperar detalles sobre una conexión específica.
ibmcloud tg connection|c GATEWAY_ID CONNECTION_ID [--output json] [-h, --help]
Opciones de comando
GATEWAY_ID-
ID de la pasarela en la que se encuentra la conexión.
CONNECTION_ID- ID de la conexión sobre la que deseas obtener información.
--output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Solicitar detalles sobre un ID de conexión específico.
ibmcloud tg c $gateway $connection
ibmcloud tg connections
Enumerar las conexiones de la pasarela de tránsito.
ibmcloud tg connections|cs GATEWAY_ID [--all-pages] [--limit NUMERIC_VALUE] [--output json] [-h, --help]
Opciones de comando
GATEWAY_ID-
ID de la pasarela para la que desea establecer conexiones.
--all-pages(Seleccionar disponibilidad en este momento)- Enumera todas las conexiones, independientemente de si se especifica un tamaño de conexión (
--limit). --limit(Seleccionar disponibilidad en este momento)- El número máximo de recursos que se pueden mostrar por página. El límite predeterminado es
100. Valores posibles:1≤ valor ≤500 --output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Ver las conexiones en la pasarela.
ibmcloud tg cs $gateway
Otros comandos requieren un ID de conexión. Guarda el ID como variable de entorno para poder utilizarlo más adelante, por ejemplo:
connection="4892849f-368e-9999-bb58-8888fb21e513"
ibmcloud tg connection-create
Crea una conexión en la pasarela de tránsito.
ibmcloud tg connection-create|cc GATEWAY_ID --name NAME --network-id NETWORK_ID --network-type NETWORK_TYPE --network-account-id ACCOUNT_ID [--zone ZONE] [--default-prefix-filter DEFAULT_PREFIX_FILTER] [--cidr CIDR] [--output json]
Opciones de comando
GATEWAY_ID-
ID de la pasarela en la que se encuentra la nueva conexión.
--name- Nombre de la nueva conexión.
--network-id- Identificador de la conexión de red. Para
classic, no establezca un valor. Utilice el CRN para todos los demás tipos de red. Por ejemplo, para averiguar el CRN de una VPC:
ibmcloud is vpc VPC_ID --json--network-type: Tipo de red de la conexión. Los valores son
classic,directlink,power_virtual_server,vpn_gateway,vpc, y.dynamic_route_serverBeta--network-account-id- ID de la cuenta de IBM Cloud que se debe utilizar para crear una conexión clásica. Solo se utiliza con el tipo
classic, cuando la cuenta de la conexión es diferente a la cuenta de la pasarela.
--zone: Opcional: zona de disponibilidad en la que se implementará un túnel GRE o una conexión VPN. Aplicable al tipo de red
vpn_gateway. Para las conexiones de dynamic_route_server Beta, se ignora el indicador--zone.No especifique `--zone` al conectar una puerta de enlace VPN regional (`availability_mode: regional`). La ubicación de la zona se deduce automáticamente a partir de la configuración de los miembros de la puerta de enlace VPN. Al especificar una zona para una puerta de enlace VPN regional, se produce un error. {: note}--default-prefix-filter: Opcional: filtro de prefijo predeterminado de la conexión (
permit|deny). No es compatible con las conexionesdynamic_route_serverBeta; si se especifica este indicador para este tipo, se produce un error.--cidr: Opcional: bloque CIDR que se utilizará para la conexión. Aplicable únicamente a los tipos de red
dynamic_route_serverBeta yvpn_gateway. Si no se especifica,198.19.174.0/23se utiliza el intervalo predeterminado para ambos tipos de conexión.--output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplos
Cree una conexión VPC que se llame vpc-connection y utilice vpcCRN="crn:v1:bluemix:public:is:us-south:a/3aa0a9999a1a46258064d84f7f447920::vpc:r134-f87014d5-87d2-46d1-9999-24683082f6bc"
ibmcloud tg cc $gateway --name vpc-connection --network-id $vpcCRN --network-type vpc
Cree una conexión clásica denominada classic-conn.
ibmcloud tg cc $gateway --name classic-conn --network-type classic
Beta
Crea una conexión de servidor de enrutamiento dinámica sin especificar un CIDR (el CIDR se asigna automáticamente):
ibmcloud tg cc $gateway \
--name drs-connection \
--network-type dynamic_route_server \
--network-id $drsCRN
Crear una conexión de servidor de rutas dinámicas con un CIDR explícito:
ibmcloud tg cc $gateway \
--name drs-connection-with-cidr \
--network-type dynamic_route_server \
--network-id $drsCRN \
--cidr 198.19.176.0/23
ibmcloud tg connection-delete
Suprimir una conexión existente.
ibmcloud tg connection-delete|cd GATEWAY_ID CONNECTION_ID [-f, --force] [-h, --help]
Opciones de comando
GATEWAY_ID-
ID de la puerta de enlace de la conexión que se está eliminando.
CONNECTION_ID- ID de la conexión que se está eliminando.
--force | -f- Opcional: Forzar la eliminación sin confirmación.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Suprimir la conexión sin confirmación.
ibmcloud tg cd $gateway $connection -f
ibmcloud tg connection-create-gre(En desuso)
Este mandato está en desuso. Utilice el comando tg-connection-gre-create.
Crea una conexión de túnel GRE (Generic Routing Encapsulation) en la pasarela de tránsito.
ibmcloud tg connection-rcreate-gre|crgre GATEWAY_ID --name NAME --zone ZONE --local-gateway-ip LOCAL_GATEWAY_IP --local-tunnel-ip LOCAL_TUNNEL_IP --remote-gateway-ip REMOTE_GATEWAY_IP --remote-tunnel-ip REMOTE_TUNNEL_IP [--base-connection-id BASE_CONNECTION_ID] [--base-network-type BASE_NETWORK_TYPE] [--network-type NETWORK_TYPE] [--network-account-id NETWORK_ACCOUNT_ID] [--remote-bgp-asn REMOTE_BGP_ASN] [--default-prefix-filter DEFAULT_PREFIX_FILTER] [--output json]
Opciones de comando
GATEWAY_ID ID de la pasarela a la que está vinculada la nueva conexión.
--name-
Nombre de la nueva conexión GRE.
--zone- Zona de disponibilidad para el túnel GRE. Ejemplo:
us-south-1 --local-gateway-ip- Dirección IP de la pasarela local para la conexión del túnel GRE.
--local-tunnel-ip- Dirección IP local del túnel para la conexión del túnel GRE.
--remote-gateway-ip- Dirección IP de la pasarela remota para la conexión del túnel GRE.
--remote-tunnel-ip- Dirección IP del túnel remoto para la conexión del túnel GRE.
--base-connection-id- Opcional: ID de la conexión de red clásica que sirve de base para el túnel GRE. Esta opción solo se puede utilizar con el tipo de red e
gre_tunnel. --base-network-type- Tipo de red de la conexión base (
classic). --network-type- Opcional: Tipo de red de la conexión GRE. El valor predeterminado es
gre_tunnel. --network-account-id- Opcional: ID de la cuenta para conectarse a una conexión clásica. Utilízalo solo con el tipo
classiccuando la cuenta de la conexión sea diferente de la cuenta de la pasarela. --remote-bgp-asn- Opcional: si no se especifica el ASN de BGP remoto, se genera uno.
--output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplos
Crea una conexión de túnel GRE denominada y gre-connection que utilice la conexión clásica 9037f710-8dfb-4948-a2bd-847c8dde96d3 como conexión base.
ibmcloud tg connection-create-gre $gateway --name gre-connection --base-connection-id 9037f710-8dfb-9999-a2bd-847c8dde96d3 --zone us-south-2 --local-gateway-ip 192.168.100.1 --local-tunnel-ip 192.168.101.1 --remote-gateway-ip 10.242.63.12 --remote-tunnel-ip 192.168.101.2
ibmcloud tg connection-approve
Aprueba una conexión desde otra cuenta como el propietario de la cuenta.
ibmcloud tg connection-approve|ca GATEWAY_ID CONNECTION_ID [-h, --help]
Opciones de comando
GATEWAY_ID-
ID de la pasarela en la que se encuentra la conexión.
CONNECTION_ID- ID de la conexión que estás aprobando.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Aprobar la solicitud de conexión.
ibmcloud tg ca $gateway $connection
ibmcloud tg connection-gre-create
Cree un túnel de encapsulación de enrutamiento genérico (GRE) o una conexión GRE no vinculada en la puerta de enlace de tránsito.
ibmcloud tg connection-gre-create|cgrec GATEWAY_ID --name NAME --zone ZONE --local-gateway-ip LOCAL_GATEWAY_IP --local-tunnel-ip LOCAL_TUNNEL_IP --remote-gateway-ip REMOTE_GATEWAY_IP --remote-tunnel-ip REMOTE_TUNNEL_IP [--base-connection-id BASE_CONNECTION_ID] [--base-network-type BASE_NETWORK_TYPE] [--network-type NETWORK_TYPE] [--network-account-id NETWORK_ACCOUNT_ID] [--remote-bgp-asn REMOTE_BGP_ASN] [--default-prefix-filter DEFAULT_PREFIX_FILTER] [--output json]
Opciones de comando
GATEWAY_ID-
ID de la pasarela a la que está vinculada la nueva conexión.
--name- Nombre de la nueva conexión GRE.
--zone- Zona de disponibilidad para el túnel GRE. Ejemplo:
us-south-1 --local-gateway-ip- Dirección IP de la pasarela local para la conexión del túnel GRE.
--local-tunnel-ip- Dirección IP local del túnel para la conexión del túnel GRE.
--remote-gateway-ip- Dirección IP de la pasarela remota para la conexión del túnel GRE.
--remote-tunnel-ip- Dirección IP del túnel remoto para la conexión del túnel GRE.
--base-connection-id- Opcional: ID de la conexión de red clásica que sirve de base para el túnel GRE. Esta opción solo se puede utilizar con el tipo de red e
gre_tunnel. --base-network-type- Opcional: Tipo de red de la conexión base (
classic). --network-type- Opcional: Tipo de red de la conexión GRE. Los valores son
gre_tunnelounbound_gre_tunnel. El valor predeterminado esgre_tunnel. --network-account-id- Opcional: ID de la cuenta para conectarse a una conexión clásica. Utilízalo solo con el tipo
classiccuando la cuenta de la conexión sea diferente de la cuenta de la pasarela. --remote-bgp-asn- Opcional: si no se especifica el ASN de BGP remoto, se genera uno.
--output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplos
Crea una conexión de túnel GRE denominada y gre-connection que utilice la conexión clásica 9037f710-8dfb-4948-a2bd-847c8dde96d3 como conexión base.
ibmcloud tg connection-gre-create $gateway --name gre-connection --base-connection-id 9037f710-8dfb-9999-a2bd-847c8dde96d3 --zone us-south-2 --local-gateway-ip 192.168.100.1 --local-tunnel-ip 192.168.101.1 --remote-gateway-ip 10.242.63.12 --remote-tunnel-ip 192.168.101.2
ibmcloud tg connection-reject
Rechaza una conexión desde otra cuenta como el propietario de la cuenta.
ibmcloud tg connection-reject|cr GATEWAY_ID CONNECTION_ID [-h, --help]
Opciones de comando
GATEWAY_ID-
ID de la pasarela en la que se encuentra la conexión.
CONNECTION_ID- ID de la conexión que estás rechazando.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Rechazar la solicitud de conexión.
ibmcloud tg cr $gateway $connection
ibmcloud tg connection-rgre-create
Cree una conexión GRE redundante en la pasarela de tránsito.
Debe utilizar un archivo JSON como entrada.
ibmcloud tg connection-rgre-create|crgrec --file JSON_FILE_PATH [--output json]
Archivo JSON
{
"gateway_id": "47f11b01-471c-47d0-9e84-550c88c94055",
"name": "redundant_gre1",
"network_type": "redundant_gre",
"base_network_type": "classic",
"network_account_id": "28e4d90ac7504be694471ee66e70d0d5",
"network_id": "crn:v1:bluemix:public:is:us-south:a/123456::vpc:4727d842-f94f-4a2d-824a-9bc9b02c523b",
"tunnels": [
{
"local_gateway_ip": "192.168.100.1",
"local_tunnel_ip": "192.168.129.2",
"name": "gre1",
"remote_bgp_asn": 65010,
"remote_gateway_ip": "10.242.63.12",
"remote_tunnel_ip": "192.168.129.1",
"zone": {
"name": "us-south-1"
}
}, {
"local_gateway_ip": "192.168.101.1",
"local_tunnel_ip": "192.168.128.2",
"name": "gre2",
"remote_bgp_asn": 65010,
"remote_gateway_ip": "10.242.63.12",
"remote_tunnel_ip": "192.168.128.1",
"zone": {
"name": "us-south-1"
}
}
]
}
Opciones de comando
gateway_id-
ID de la puerta de enlace en la que se encuentra la nueva conexión GRE redundante.
name- Nombre de la nueva conexión GRE redundante.
network_type- Tipo de red de la conexión. El valor es
redundant_gre.
base_network_typeEl tipo de red que se va a utilizar. Las opciones sonclassicyvpc.network_account_id- ID de la cuenta de IBM Cloud que se utilizará para una red clásica entre cuentas. Solo se utiliza con el tipo
classic, cuando la cuenta de la conexión es diferente a la cuenta de la pasarela. Esta opción no es válida para el tipo de red básicavpc. network_id- El CRN de la red VPC que se va a utilizar. Esta opción no es válida para el tipo de red básica
classic. Por ejemplo, para averiguar el CRN de una VPC:
ibmcloud is vpc VPC_ID --jsontunnels-
Información para los túneles del GRE.
local_gateway_ip-
Dirección IP de la pasarela local para la conexión del túnel GRE. Este campo es obligatorio para las conexiones de tipo red
redundant_gre.Cuando se utiliza un tipo de red base
vpc, esta dirección IP debe cumplir con el RFC 1918 y no ser una dirección IP dentro del rango de multidifusión de224.0.0.0a239.255.255.255y no puede estar en conflicto con ninguna red existente que esté conectada a la pasarela de tránsito. Además, esta dirección IP no puede utilizarse comolocal-gateway-ippara otro GRE que utilice la misma red subyacente. local_tunnel_ip-
Dirección IP del túnel local asignada al lado del túnel de Transit Gateway. Las direcciones
remote_tunnel_ipylocal_tunnel_ipdeben pertenecer a la misma/30red. Ninguna de las dos puede ser la dirección de red ni de difusión. Este campo es obligatorio para conexiones de tipo redredundant_gre. name-
Nombre del túnel GRE.
remote_bgp_asn-
Opcional: si no se especifica el ASN de BGP remoto, se genera uno.
remote_gateway_ip-
Dirección IP de la pasarela remota para la conexión del túnel GRE.
remote_tunnel_ip-
Dirección IP del túnel remoto para la conexión del túnel GRE.
zone-
Zona de disponibilidad para el túnel GRE. Ejemplo:
us-south-1
ibmcloud tg connection-update
Actualizar las propiedades de una conexión existente.
ibmcloud tg connection-update|cu GATEWAY_ID CONNECTION_ID --name NAME [--output json] [-h, --help]
Opciones de comando
GATEWAY_ID-
ID de la pasarela en la que se está actualizando la conexión.
CONNECTION_ID- ID de la conexión que se va a actualizar.
--name- Nuevo nombre de la conexión.
--default-prefix-filter- Opcional: filtro de prefijo predeterminado de la conexión (
permit|deny). --output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Actualizar el nombre de la conexión a MyConn2.
ibmcloud tg cu $gateway $connection --name MyConn2
ibmcloud tg redundant-gre-tunnel-add
Añadir un túnel a un GRE redundante.
ibmcloud tg redundant-gre-tunnel-add|targre GATEWAY_ID REDUNDANT_GRE_ID --name NAME --zone ZONE --local-gateway-ip LOCAL_GATEWAY_IP --local-tunnel-ip LOCAL_TUNNEL_IP --remote-gateway-ip REMOTE_GATEWAY_IP --remote-tunnel-ip REMOTE_TUNNEL_IP [--remote-bgp-asn REMOTE_BGP_ASN] [--output json]
Opciones de comando
GATEWAY_ID-
ID de la pasarela a la que está vinculada la nueva conexión.
REDUNDANT_GRE_ID- ID de la conexión GRE redundante.
--name- Nombre del nuevo túnel GRE.
--zone- Zona de disponibilidad para el túnel GRE. Ejemplo:
us-south-1 --local-gateway-ip- Dirección IP de la pasarela local para la conexión del túnel GRE.
--local-tunnel-ip- Dirección IP local del túnel para la conexión del túnel GRE.
--remote-gateway-ip- Dirección IP de la pasarela remota para la conexión del túnel GRE.
--remote-tunnel-ip- Dirección IP del túnel remoto para la conexión del túnel GRE.
--remote-bgp-asn- Opcional: si no se especifica el ASN de BGP remoto, se genera uno.
--output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
ibmcloud tg redundant-gre-tunnel-add e47d6b9c-095f-4d31-aa47-5c89c2ded820 e4e37e31-8895-4594-be6b-61e8088b53c7 --name gre-tunnel3 --zone us-south-3 --local-gateway-ip 192.193.202.1 --local-tunnel-ip 192.193.237.2 -ibmcloud login -a https://cloud.ibm.com -r us-south --sso -remote-gateway-ip 10.186.203.5 --remote-tunnel-ip 192.193.237.1
ibmcloud tg redundant-gre-tunnel-remove
Eliminar un túnel de un GRE redundante.
ibmcloud tg redundant-gre-tunnel-remove|trrgre GATEWAY_ID REDUNDANT_GRE_ID TUNNEL_ID [--force | -f] [--help | -h]
Opciones de comando
GATEWAY_ID-
ID de la pasarela a la que está vinculada la nueva conexión.
REDUNDANT_GRE_ID- ID de la conexión GRE redundante.
TUNNEL_ID- ID del túnel que se va a eliminar.
--force | -f- Opcional: Forzar la eliminación sin confirmación.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
ibmcloud tg redundant-gre-tunnel-remove e47d6b9c-095f-4d31-aa47-5c89c2ded820 e4e37e31-8895-4594-be6b-61e8088b53c7 b97a5cf5-7ee4-4073-b719-f6df36dea08f
ibmcloud tg tunnels
Enumere todos los túneles bajo un GRE redundante dado.
ibmcloud tg tunnels|ts GATEWAY_ID REDUNDANT_GRE_ID [--output json]
Opciones de comando
GATEWAY_ID-
ID de la pasarela a la que está vinculada la nueva conexión.
REDUNDANT_GRE_ID- ID de la conexión GRE redundante.
--output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--force | -f- Opcional: Forzar la eliminación sin confirmación.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
ibmcloud tg ts e47d6b9c-095f-4d31-aa47-5c89c2ded820 e4e37e31-8895-4594-be6b-61e8088b53c7
Ubicaciones
Esta sección ofrece información sobre comandos de la interfaz de línea de comandos (CLI) para las funciones de localización.
ibmcloud tg locations
Utilice este mandato para ver una lista de las ubicaciones posibles en la que puede crear una pasarela.
ibmcloud tg locations|locs [--output json] [-h, --help]
Opciones de comando
--output json-
Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
ibmcloud tg location
Recupera información específica de esta ubicación.
ibmcloud tg location|loc NAME [--output json] [-h, --help]
Opciones de comando
NAME-
Nombre de la ubicación sobre la que desea obtener información.
--output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Solicitar detalles sobre la ubicación us-south.
ibmcloud tg location us-south
Filtros de prefijo de conexión
Esta sección proporciona información sobre los comandos CLI para las funciones de filtro de prefijo de conexión.
ibmcloud tg prefix-filter-create
Añadir filtro de prefijo a la conexión.
ibmcloud tg prefix-filter-create GATEWAY_ID CONNECTION_ID --prefix PREFIX --action ACTION [--le LE] [--ge GE] [--before BEFORE] [--output json]
Opciones de comando
GATEWAY_ID-
ID de la puerta de enlace a la que se aplica el filtro de prefijos.
CONNECTION_ID- ID de la conexión a la que se aplica el filtro de prefijos.
--prefix- Prefijo de red al que se aplica el filtro.
--action- Acción que se debe realizar con el prefijo especificado (
permit|deny). --le- Opcional: filtro de prefijo que se aplica a una máscara de subred menor o igual que este valor.
--ge- Opcional: filtro de prefijo que se aplica a una máscara de subred mayor o igual que este valor.
--before- Opcional: identificador del filtro de prefijo al que debe aplicarse este filtro. Si está vacío, este filtro se aplica en último lugar.
--output- Opcional: Especifica el formato de salida; solo
jsonse admite. Se muestran todos los detalles.
Ejemplos
Añada el filtro de prefijo para 10.0.250.0/24 a la pasarela 9f559c43-63f4-4da5-b312-b525a8dce185, conexión 6c1bdc19-4adb-4760-8cdc-ef3b74b626f7 con la acción permit.
ibmcloud tg pfc 9f559c43-63f4-4da5-b312-b525a8dce185 6c1bdc19-4adb-4760-8cdc-ef3b74b626f7 --prefix 10.0.250.0/24 --action permit
ibmcloud tg prefix-filter-delete
Suprimir el filtro de prefijo de la conexión.
ibmcloud tg prefix-filter-delete GATEWAY_ID CONNECTION_ID FILTER_ID [-f, --force]
Opciones de comando
GATEWAY_ID-
ID de la pasarela de la que se elimina el filtro de prefijos.
CONNECTION_ID- ID de la conexión de la que se elimina el filtro de prefijos.
FILTER_ID- ID del filtro de prefijos que se va a eliminar.
--force, -f- Forzar la operación de eliminación sin confirmación.
Ejemplos
Suprimir el ID de filtro de prefijo b4dbe0a6-c52d-4128-cc32-6f53d86bc82b de la pasarela 9f559c43-63f4-4da5-b312-b525a8dce185 y la conexión 6c1bdc19-4adb-4760-8cdc-ef3b74b626f7
ibmcloud tg pfd 9f559c43-63f4-4da5-b312-b525a8dce185 6c1bdc19-4adb-4760-8cdc-ef3b74b626f7 b4dbe0a6-c52d-4128-cc32-6f53d86bc82b
Informes de ruta
Esta sección ofrece información sobre comandos de la interfaz de línea de comandos (CLI) para las funciones de informe de rutas.
ibmcloud tg route-reports
Utilice este mandato para listar los informes de ruta disponibles en una pasarela.
ibmcloud tg route-reports|rrs GATEWAY_ID [--output json] [-h, --help]
Opciones de comando
GATEWAY_ID-
ID de la pasarela para la que se desean mostrar los informes de rutas.
--output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Liste los informes de ruta en la pasarela.
ibmcloud tg rrs $gateway
Otros comandos requieren un ID de informe de ruta. Guarda el ID como variable de entorno para poder utilizarlo más adelante, por ejemplo:
report="4892849f-368e-9999-4444-8888fb21e513"
ibmcloud tg route-report
Recupere detalles sobre un informe de ruta específico.
ibmcloud tg route-report|rr GATEWAY_ID REPORT_ID [--output json] [-h, --help]
Opciones de comando
GATEWAY_ID-
ID de la pasarela de la que procede el informe de rutas.
REPORT_ID- ID del informe de ruta sobre el que desea obtener detalles.
--output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Solicite detalles para un informe de ruta.
ibmcloud tg rr $gateway $report
ibmcloud tg route-report-create
Cree un informe de ruta.
ibmcloud tg route-report-create|rrc GATEWAY_ID [--output json] [-h, --help]
Opciones de comando
GATEWAY_ID-
ID de la pasarela para la que se crea el informe de rutas.
--output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Cree un informe de ruta para una pasarela.
ibmcloud tg rrc $gateway
ibmcloud tg route-report-delete
Suprimir un informe de ruta existente.
ibmcloud tg route-report-delete|rrd GATEWAY_ID REPORT_ID [-f, --force] [-h, --help]
Opciones de comando
GATEWAY_ID-
ID de la pasarela a la que se refiere el informe.
REPORT_ID- ID del informe que desea eliminar.
--force | -f- Opcional: Forzar la eliminación sin confirmación.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Suprimir informe de ruta sin confirmación.
ibmcloud tg rrd $gateway $report -f
Grupos de redundancia
Esta sección ofrece información sobre comandos de la interfaz de línea de comandos (CLI) para las funciones de los grupos de redundancia.
ibmcloud tg redundancy-groups
Muestra una lista de todos los grupos de redundancia de la cuenta.
ibmcloud tg redundancy-groups|rgs [--output json] [-h, --help]
Ejemplo
Muestra una lista de todos los grupos de redundancia de la cuenta.
ibmcloud tg rgs
ibmcloud tg redundancy-group
Recuperar un grupo de redundancia.
ibmcloud tg redundancy-group|rg ID [--output json] [-h, --help]
Opciones de comando
ID-
El identificador del grupo de redundancia que desea recuperar.
--output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Recuperar un grupo de redundancia.
ibmcloud tg rg $redundancy_group_id
ibmcloud tg redundancy-group-update
Actualiza el grupo de redundancia.
ibmcloud tg redundancy-group-update|rgu ID --name NEW_NAME [--output json] [-h, --help]
Opciones de comando
ID-
El identificador del grupo de redundancia que desea actualizar.
--name NEW_NAME- El nuevo nombre del grupo de redundancia. No se puede utilizar un nombre que ya esté en uso en la cuenta.
--output json- Opcional: especifica si deseas que el resultado se muestre en formato JSON.
--help | -h- Opcional: Obtener ayuda sobre este comando.
Ejemplo
Actualizar un grupo de redundancia.
ibmcloud tg rgu $redundancy_group_id --name NEW_NAME